==> dojo-1.11.4.tgz: package/cldr/nls/id/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h.mm a",
	"days-standAlone-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "sekarang",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Hari dalam Seminggu",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E, d/M/y",
	"field-wed-relative+0": "Rabu ini",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-wed-relative+1": "Rabu berikutnya",
	"eraNarrow": [
		"SM",
		"M"
	],
	"field-tue-relative+-1": "Selasa lalu",
	"days-format-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormat-long": "d MMMM y",
	"field-fri-relative+-1": "Jumat lalu",
	"field-wed-relative+-1": "Rabu lalu",
	"months-format-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE, dd MMMM y",
	"field-thu-relative+-1": "Kamis lalu",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-yMd": "d/M/y",
	"dateFormatItem-yM": "M/y",
	"field-era": "Era",
	"months-standAlone-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"timeFormat-long": "HH.mm.ss z",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-year": "Tahun",
	"field-hour": "Jam",
	"months-format-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agt",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"field-sat-relative+0": "Sabtu ini",
	"field-sat-relative+1": "Sabtu berikutnya",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "hari ini",
	"field-day-relative+1": "besok",
	"field-thu-relative+0": "Kamis ini",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "lusa",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agt",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "Minggu ini",
	"dateFormatItem-Hm": "HH.mm",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-sun-relative+1": "Minggu berikutnya",
	"eraAbbr": [
		"SM",
		"M"
	],
	"field-minute": "Menit",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "kemarin",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"dayPeriods-format-narrow-am": "AM",
	"field-day-relative+-2": "kemarin lusa",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "Jumat ini",
	"field-fri-relative+1": "Jumat berikutnya",
	"field-day": "Hari",
	"days-format-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"field-zone": "Zona Waktu",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "tahun lalu",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-hm": "h.mm a",
	"days-format-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormatItem-yMMMd": "d MMM y",
	"eraNames": [
		"SM",
		"M"
	],
	"days-format-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"days-standAlone-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Bulan",
	"field-tue-relative+0": "Selasa ini",
	"field-tue-relative+1": "Selasa berikutnya",
	"dayPeriods-format-wide-am": "AM",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"dateFormatItem-EHm": "E HH.mm",
	"field-mon-relative+0": "Senin ini",
	"field-mon-relative+1": "Senin berikutnya",
	"dateFormat-short": "dd/MM/yy",
	"dateFormatItem-EHms": "E HH.mm.ss",
	"dateFormatItem-Ehms": "E h.mm.ss a",
	"field-second": "Detik",
	"field-sat-relative+-1": "Sabtu lalu",
	"dateFormatItem-yMMMEd": "E, d MMM y",
	"field-sun-relative+-1": "Minggu lalu",
	"field-month-relative+0": "bulan ini",
	"field-month-relative+1": "Bulan berikutnya",
	"dateFormatItem-Ed": "E, d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Minggu",
	"dateFormat-medium": "d MMM y",
	"field-year-relative+0": "tahun ini",
	"field-week-relative+-1": "minggu lalu",
	"field-year-relative+1": "tahun depan",
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "Senin lalu",
	"field-week-relative+0": "minggu ini",
	"field-week-relative+1": "Minggu berikutnya"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/id/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h.mm a",
	"days-standAlone-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "sekarang",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "Hari dalam Seminggu",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E, d/M/y",
	"field-wed-relative+0": "Rabu ini",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-wed-relative+1": "Rabu berikutnya",
	"eraNarrow": [
		"SM",
		"M"
	],
	"field-tue-relative+-1": "Selasa lalu",
	"days-format-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormat-long": "d MMMM y",
	"field-fri-relative+-1": "Jumat lalu",
	"field-wed-relative+-1": "Rabu lalu",
	"months-format-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE, dd MMMM y",
	"field-thu-relative+-1": "Kamis lalu",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-yMd": "d/M/y",
	"dateFormatItem-yM": "M/y",
	"field-era": "Era",
	"months-standAlone-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"timeFormat-long": "HH.mm.ss z",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-year": "Tahun",
	"field-hour": "Jam",
	"months-format-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agt",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"field-sat-relative+0": "Sabtu ini",
	"field-sat-relative+1": "Sabtu berikutnya",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "hari ini",
	"field-day-relative+1": "besok",
	"field-thu-relative+0": "Kamis ini",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "lusa",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agt",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "hari Minggu ini",
	"dateFormatItem-Hm": "HH.mm",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-sun-relative+1": "hari Minggu berikutnya",
	"eraAbbr": [
		"SM",
		"M"
	],
	"field-minute": "Menit",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "kemarin",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"dayPeriods-format-narrow-am": "AM",
	"field-day-relative+-2": "kemarin lusa",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "Jumat ini",
	"field-fri-relative+1": "Jumat berikutnya",
	"field-day": "Hari",
	"days-format-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"field-zone": "Zona Waktu",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "tahun lalu",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-hm": "h.mm a",
	"days-format-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormatItem-yMMMd": "d MMM y",
	"eraNames": [
		"Sebelum Masehi",
		"M"
	],
	"days-format-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"days-standAlone-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Bulan",
	"field-tue-relative+0": "Selasa ini",
	"field-tue-relative+1": "Selasa berikutnya",
	"dayPeriods-format-wide-am": "AM",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"dateFormatItem-EHm": "E HH.mm",
	"field-mon-relative+0": "Senin ini",
	"field-mon-relative+1": "Senin berikutnya",
	"dateFormat-short": "dd/MM/yy",
	"dateFormatItem-EHms": "E HH.mm.ss",
	"dateFormatItem-Ehms": "E h.mm.ss a",
	"field-second": "Detik",
	"field-sat-relative+-1": "Sabtu lalu",
	"dateFormatItem-yMMMEd": "E, d MMM y",
	"field-sun-relative+-1": "hari Minggu lalu",
	"field-month-relative+0": "bulan ini",
	"field-month-relative+1": "Bulan berikutnya",
	"dateFormatItem-Ed": "E, d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Minggu",
	"dateFormat-medium": "d MMM y",
	"field-year-relative+0": "tahun ini",
	"field-week-relative+-1": "minggu lalu",
	"field-year-relative+1": "tahun depan",
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "Senin lalu",
	"field-week-relative+0": "minggu ini",
	"field-week-relative+1": "minggu berikutnya"
}
//end v1.x content
);
